/* $Id: adjintnat.cpp,v 1.4 2007/07/23 09:36:12 cvsroot Exp $ */

/* DGAP - General Analytical Positioning
 * Copyright (C) 2005 Dirk Stallmann
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#include "adjintnat.h"
#include "cholesky.h"

namespace DEP
{

// solve normal equation system

int AdjInterfaceNative::solve(Matrix<double>& atpa, Vector<double>& atpl,
Vector<double>& x, Vector<double>& dec)
{
	// Step 1: Cholesky decomposition
	int info = chol_dec(atpa, dec);
	if (info != 0)
		{
		cout << "ERROR: Cholesky decomposition failed.\n";
		return info;
		}

	// Step 2: solving by backsubstitution
	info = chol_sol(atpa, dec, atpl, x);
	if (info != 0)
		{
		cout << "ERROR: Backsubstitution failed.\n";
		return info;
		}
		
	return 0;
}


// inversion of normal matrix

int AdjInterfaceNative::inversion(Matrix<double>& atpa, Matrix<double>& qxx,
Vector<double>& dec)
{
	qxx = atpa;
	int info = chol_inv(qxx, dec);
	if (info != 0)
		{
		cout << "ERROR: Backsubstitution failed.\n";
		return info;
		}
		
	qxx.make_upper_symmetric();

	return 0;
}

} // namespace DEP
