/**********************************************************************/
//
// FILE:    caminscfg.h
//          Camera-INS configuration class.
// CREATED: 01 Sep 03  (ds)
// CHANGES: 
// REFS:    
//
// (c) 2003 Dirk Stallmann (ds)/ IfP Uni Stuttgart
/**********************************************************************/

#ifndef DEP_CAMINSCFG_INCLUDED
#define DEP_CAMINSCFG_INCLUDED

#include "adjobj.h"

using namespace std;
using namespace GenLib2;

namespace DEP
{

/** Camera-INS configuration class.
 *  Imaging geometry to model offset and misaligment
 *  between the camera and INS frame.
 * 
 *  Parameters: 3 translations, 4 rotations using quaternion
 *  Constraints: 1 between the rotation parameters
 *   
 *  @author Dirk Stallmann
 */
class CamINSConfig : public AdjObject
{
public:
	/// constructor
	CamINSConfig();

	/**@name overridden base class members of AdjObject */
	//@{
		/// get type name
		string type_str() const;

		/// get key name
		string key_str() const;
	
		//// get parameter name
		string uname(size_t i) const;
	//@}

	/**@name overridden class members of ExtOrientation */
	//@{
		/// get partial derivatives of rotation parameters
		//void get_derivs_rot(DerivSub& deriv_eo) const;

		/// calculate rotation parameters from rotation matrix
		//virtual void calc_rot_params(vector<double>& a,
		//	const RotMatrix3<double>& R) const {
		//	R.get_quaternion(a[0], a[1], a[2], a[3]);
		//}

		/// calculate rotation matrix from rotation parameters
		//virtual void calc_rot_matrix(RotMatrix3<double>& R,
		//	const vector<double>& a) const {
		//	R.set_quaternion(a[0], a[1], a[2], a[3]);
		//}
	//@}

protected:
	/// rotation parameters
	//vector<double>	_rot_params;

	/// rotation matrix
	RotMatrix3<double>	_rot_matrix;
};


// non-member functions ...

} // namespace DEP

#endif
