/* $Id: eoopkfix.h,v 1.10 2007/07/23 09:38:58 cvsroot Exp $ */

/* DGAP - General Analytical Positioning
 * Copyright (C) 2005 Dirk Stallmann
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#ifndef DEP_EOOPKFIX_INCLUDED
#define DEP_EOOPKFIX_INCLUDED

#include "eopokrot.h"

using namespace std;
using namespace GenLib2;

namespace DEP
{

/** Exterior orientation using euler angles.
 *   
 *    Parameters            : 3 rotation angles (euler angles)
 *    Coordinate axes       : fixed
 *    Sequence of rotations : Rz(kappa) * Ry(phi) * Rx(omega)
 *    Direction of rotation : clockwise
 *
 *  @author Dirk Stallmann
 */
class EOAnglesOPKFix : public EOAnglesPOKRot
{
public:
	/// constructor
	EOAnglesOPKFix() : EOAnglesPOKRot() {}

	/**@name overridden base class members of AdjObject */
	//@{
		/// get type name
		string type_str() const;

		/// get key name
		string key_str() const;
	
		/// get parameter name
		string uname(size_t i) const;
	//@}

	/**@name resolved pure virtual methods of class ExtOrientation */
	//@{
		/// calculate rotation parameters from rotation matrix
		void calc_rot_params(vector<double>& a, const DRotMatrix3& R) const
		{
			assert(a.size() == 3);
			R.get_angles_opk_fix(a[0], a[1], a[2]);
		}
		
		/// calculate rotation matrix
		void calc_rot_matrix(DRotMatrix3& R, const vector<double>& a) const
		{
			assert(a.size() == 3);
			R.set_angles_opk_fix(a[0], a[1], a[2]);
		}
	//@}
	
private:
	/// calculate partial derivatives of the rotation matrix
	void dr(double omega, double phi, double kappa,
	DRotMatrix3& dR_om, DRotMatrix3& dR_ph, DRotMatrix3& dR_ka) const
	{
		derivs_opk_fix_cw(omega, phi, kappa, dR_om, dR_ph, dR_ka);
	}
};


// non-member functions ...

} // namespace DEP

#endif
