/* $Id: imgpnt.h,v 1.7 2007/07/23 09:40:04 cvsroot Exp $ */

/* DGAP - General Analytical Positioning
 * Copyright (C) 2005 Dirk Stallmann
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#ifndef DEP_IMGPNT_INCLUDED
#define DEP_IMGPNT_INCLUDED

#include "depdef.h"

using namespace std;
using namespace GenLib2;

namespace DEP
{
class Image;

/** Image point class.
 *  The image point class holds the information of a point in image space:
 *  the point identifier (ID), the coordinates and their standard deviations.
 *  No assumption will be made about the units of the image points
 *  coordinates and their standard deviations (e.g. pixel or metric).
 *  Valid point ID's are positive numbers, negative numbers will be ignored.
 *
 *  @author Dirk Stallmann
 */
class ImagePoint
{
	friend class Image;

public:
	/// contructor
	ImagePoint() : _id(), crds(), sdev() { }

	/// set ID
	void set_id(const string& id) { _id = id; }

	/// get ID
	const char* get_id() const { return _id.c_str(); }

	/// read image point
	bool read(istream& is);

	/// point ID
	string			_id;

	/// coords.
	DPoint2		crds;

	/// std. dev.
	DPoint2		sdev;
};


// non-member functions ...

/// append or replace image point
bool add_image_point(vector<ImagePoint*>& impts, ImagePoint* ip);

/// find image point by id, return index
int find_image_point(const vector<ImagePoint*>& impts, const string& id);

/// count number of image points
int count_image_points(const vector<ImagePoint*>& impts);

} // namespace DEP

#endif
