/**********************************************************************/
//
// FILE:    imuquat.h
//          IMU misalignment class using quaternion parametrisation.
// CREATED: 01 Nov 04  (ds)
// CHANGES:
// REFS:
//
// (c) 2004 Dirk Stallmann (ds)/ IfP Uni Stuttgart
/**********************************************************************/

#ifndef DEP_IMUQUAT_INCLUDED
#define DEP_IMUQUAT_INCLUDED

#include "imumis.h"

using namespace std;
using namespace GenLib2;

namespace DEP
{

/** IMU misalignment class using unit quaternion parametrisation.
 *
 *  @author Dirk Stallmann
 */
class IMUMisalignmentQuaternion : public IMUMisalignment
{
public:
	/// constructor
	IMUMisalignmentQuaternion() : IMUMisalignment(4) {};
	
	/**@name overridden base class members of AdjObject */
	//@{
		/// get type name
		string type_str() const;

		/// get key name
		string key_str() const;

		/// get parameter name
		string uname(size_t i) const;

		/// get number of constraints
		size_t num_con() const { return 1; }

		/// add weighted constraints
		void add_constraints(Matrix<double>& atpa,
			Vector<double>& atpl, double& ltpl) const;
	//@}
	
	/**@name overridden class members of IMUMisalignment */
	//@{
		/// calculate rotation parameters from rotation matrix
		void calc_rot_params(vector<double>& a,
		const DRotMatrix3& M) const
		{
			assert(a.size() == 4);
			M.get_quaternion(a[0], a[1], a[2], a[3]);
		}

		/// get rotation matrix from rotation parameters
		void get_rot_matrix(DRotMatrix3& M) const
		{
			assert(_a.size() == 4);
			M.set_quaternion(_a[0], _a[1], _a[2], _a[3]);
		}
		
		/// calculate derivatives
		void calc_derivs(DerivSub& deriv,
			double h, double u, double v, double w,
			const DPoint3& d, const DRotMatrix3& R) const;
	//@}

protected:	
	/// differential rotation matrices
	void dm(DRotMatrix3& dM_m0, DRotMatrix3& dM_m1,
	DRotMatrix3& dM_m2, DRotMatrix3& dM_m3) const
	{
		assert(_a.size() == 4);
		derivs_quaternion(_a[0], _a[1], _a[2], _a[3],
			dM_m0, dM_m1, dM_m2, dM_m3);
	}
};


// non-member functions ...

} // namespace DEP

#endif
